/**
 *
 */
type LogLevel = "debug" | "info" | "warn" | "error";
declare global {
    /**
     * Whether or not to enable debug mode. When enabled, default log level of `info`
     */
    var __GILL_DEBUG__: boolean | undefined;
    /**
     * Set the a desired level of logs to be output in the application
     *
     * - Default: `info`
     * - Options: `debug` | `info` | `warn` | `error`
     */
    var __GILL_DEBUG_LEVEL__: LogLevel | undefined;
}
/**
 * Check if the `gill` debug logger is enabled or not
 */
export declare const isDebugEnabled: () => boolean;
/**
 * Log debug messages based on the desired application's logging level.
 *
 * @param message - the message contents to be logged
 * @param level - default: `info` (see: {@link GILL_LOG_LEVELS})
 * @param prefix - default: `[GILL]`
 *
 * To enable gill's debug logger, set any of the following to `true`:
 * - `process.env.GILL_DEBUG`
 * - `global.__GILL_DEBUG__`
 * - `window.__GILL_DEBUG__`
 *
 * To set a desired level of logs to be output in the application, set the value of one of the following:
 * - `process.env.GILL_DEBUG_LEVEL`
 * - `global.__GILL_DEBUG_LEVEL__`
 * - `window.__GILL_DEBUG_LEVEL__`
 */
export declare function debug(message: unknown, level?: LogLevel, prefix?: string): void;
export {};
//# sourceMappingURL=debug.d.ts.map